# naive pooled approach to PDX data

require(readxl)
require(tidyverse)
require(minpack.lm)
require(broom)
require(writexl)

# Data Cleaning and Manipulation ------------------------------------------

#import raw xenograft data
raw_data<- read_xlsx("nm.3954-S2.xlsx", sheet = "PCT raw data", col_names = T)

#rename column names for ease of use when doing t-test
colnames(raw_data)<- c("Model" ,"Tumor.Type", "Treatment", "Volume.mm3",
                       "body.weight.g", "Days.Post.T0", "%.TVol.Difference",
                       "%.BW.Difference")

#filter for first 28 days of study (typical length of xenograft study)
xeno28<- raw_data %>%
  filter(Days.Post.T0 <= 28)

#histogram-days postT0
ggplot(xeno28, 
       aes(x = Days.Post.T0))+
  geom_histogram(binwidth=.5, colour="black", fill = "black") +
  labs(x = "Day", y = "Count")  +
  theme_bw()

#from histograms it seems like most measurement were taken days, 3,7,10,14,21,28 

#filter for first 14 days of study
xeno14<- raw_data %>%
  filter(Days.Post.T0 <= 14)

#filter for 14st day measurement
xeno_last14<- xeno14 %>% 
  filter(Days.Post.T0 == 14)

#filter for first 21 days of study
xeno21<- raw_data %>%
  filter(Days.Post.T0 <= 21)

#filter for 21st day measurement
xeno_last21<- xeno21 %>% 
  filter(Days.Post.T0 == 21)

#filter for last measured timepoint (28 days)
xeno_last28<- xeno28 %>% 
  filter(Days.Post.T0 == 28)

#create array of unique models which were trialed with  treatment
#and without

#dataframe of all untreated models (14th day)
ctrl14<- xeno_last14[xeno_last14$Treatment == "untreated",]
#dataframe of all models that were treated
trt14<- xeno_last14[xeno_last14$Treatment != "untreated",]

#dataframe of all untreated models (21st day)
ctrl21<- xeno_last21[xeno_last21$Treatment == "untreated",]
#dataframe of all models that were treated
trt21<- xeno_last21[xeno_last21$Treatment != "untreated",]

#dataframe of all untreated models (28th day)
ctrl28<- xeno_last28[xeno_last28$Treatment == "untreated",]
#dataframe of all models that were treated
trt28<- xeno_last28[xeno_last28$Treatment != "untreated",]

#filter for models that have both control arm (untreated) and treatments
xeno_filt14<- trt14[trt14$Model %in% ctrl14$Model, ]
xeno_filt21<- trt21[trt21$Model %in% ctrl21$Model, ]
xeno_filt28<- trt28[trt28$Model %in% ctrl28$Model, ]

#create long data frame of models which were both treated 
#and had control arm untreated treatment)
long_xeno_last14<- rbind(xeno_filt14, ctrl14)
long_xeno_last21<- rbind(xeno_filt21, ctrl21)
long_xeno_last28<- rbind(xeno_filt28, ctrl28)

#array of every treatment
unique_trt14<- unique(long_xeno_last14[long_xeno_last14$Treatment!= "untreated",]$Treatment)
unique_trt21<- unique(long_xeno_last21[long_xeno_last21$Treatment!= "untreated",]$Treatment)
unique_trt28<- unique(long_xeno_last28[long_xeno_last28$Treatment!= "untreated",]$Treatment)

# I think it should be an un-paired t-test as each animal has not been used for both
# control and treated

xeno14$Rad<- ((3/(4*pi))*xeno14$Volume.mm3)^(1/3)
colnames(xeno14)[6]<-"Days"

xeno21$Rad<- ((3/(4*pi))*xeno21$Volume.mm3)^(1/3)
colnames(xeno21)[6]<-"Days"

xeno28$Rad<- ((3/(4*pi))*xeno28$Volume.mm3)^(1/3)
colnames(xeno28)[6]<-"Days"


# Day 14 Analysis ---------------------------------------------------------

# models for nlsLM
linear_growth_1<-function(r0,g,data) { 
  
  # time
  time <- data$Days
  # tumour growth
  ypred<-r0+g*time

  
  return(ypred)
}

linear_growth_2<-function(r0,g,d,data) { 
  # time
  time <- data$Days
  # treatment effect
  trt <- data$Treatment
  # tumour growth
  ypred<- r0+(g-d*trt)*time

  return(ypred)
}

# for loop to perform analysis for each treatment
p_vals14<- array(NA, dim = c(length(unique_trt14),5))
for(i in 1:length(unique_trt14)){
  tryCatch({
    #print treatment
    print(unique_trt14[i])
    #filter for treatment i and control arm for when model numbers match
    trt_dat14<- long_xeno_last14 %>% 
      filter(Treatment %in% c(unique_trt14[i], "untreated"))%>%
      filter(Model %in% long_xeno_last14[long_xeno_last14$Treatment==unique_trt14[i],]$Model)
    #perform paired t test for treatment i
    t_out14<- t.test(Volume.mm3 ~ Treatment, 
                     data=trt_dat14, 
                     paired=FALSE)# not sure this is really paired data
    #print t-test result
    print(t_out14)
    
    id14<-trt_dat14$Model# want to find these ids for time-series
    # create data-set for lme
    trt_dat14<- xeno14 %>% 
      filter(Treatment %in% c(unique_trt14[i], "untreated"))%>%
      filter(Model %in% xeno14[xeno14$Treatment==unique_trt14[i],]$Model)
    # select those with same Model name as that used
    trt_dat14<-trt_dat14 %>%
      filter(Model %in% id14)
    
    # perform model fits and output likelihood ratio-test
    trt_dat14<-trt_dat14[is.na(trt_dat14$Rad)==F,]
    trt_dat14$Treatment<-as.numeric(trt_dat14$Treatment!="untreated")

    model1 <- nlsLM(Rad ~ linear_growth_1(r0,g,data=trt_dat14),
                    trt_dat14, start = c(r0=3,g=0.01))
    
    # add treatment effect
    model2 <- nlsLM(Rad ~ linear_growth_2(r0,g,d,data=trt_dat14),
                    trt_dat14, start = c(r0=3,g=0.01,d=0.1))
    
    # anova test
    var_nls <- anova(model1, model2)
    var_nls
    # tidy format
    var_nls <- tidy(var_nls) 
    
    
    
    #create array of p-values
    p_vals14[i,1]<- unique_trt14[i]
    p_vals14[i,2]<- t_out14$p.value
    # TGI is defined as: 100*(V(control,t)-Volume(treated,t))/(V(control,t)-V(control,0))
    p_vals14[i,3]<-  100*as.numeric((t_out14$estimate[1]-t_out14$estimate[2])/
                                      (t_out14$estimate[2]-mean(trt_dat14$Volume.mm3[trt_dat14$Treatment==0 & trt_dat14$Days==0])))# this is measure of tumour growth inhibition
    
    p_vals14[i,4]<- as.numeric(t_out14$estimate[2]/
                                 t_out14$estimate[1])# this is measure of tumour growth inhibition
    p_vals14[i,5]<- var_nls$p.value[2]
    
  }, error=function(e){cat("ERROR :",conditionMessage(e), "\n")})
}

#Output t-test results 
#Dataframe of treatment and their p-value
p_vals14<- as_tibble(p_vals14)

#assign column names
colnames(p_vals14)<- c("Treatment","T-test","TGI","FoldChange","LRT")


#coerce p-values & TGI to numeric 
p_vals14$`T-test`<- as.numeric(as.character(p_vals14$`T-test`))
p_vals14$TGI<- as.numeric(as.character(p_vals14$TGI))
p_vals14$FoldChange<- as.numeric(as.character(p_vals14$FoldChange))
p_vals14$LRT<- as.numeric(as.character(p_vals14$LRT))

#view results
p_vals14

pval_limit<- 0.05


# Day 21 Analysis ---------------------------------------------------------

# for loop to perform analysis for each treatment
p_vals21<- array(NA, dim = c(length(unique_trt21),5))
for(i in 1:length(unique_trt21)){
  tryCatch({
    #print treatment
    print(unique_trt21[i])
    #filter for treatment i and control arm for when model numbers match
    trt_dat21<- long_xeno_last21 %>% 
      filter(Treatment %in% c(unique_trt21[i], "untreated"))%>%
      filter(Model %in% long_xeno_last21[long_xeno_last21$Treatment==unique_trt21[i],]$Model)
    #perform paired t test for treatment i
    t_out21<- t.test(Volume.mm3 ~ Treatment, 
                     data=trt_dat21, 
                     paired=FALSE)# not sure this is really paired data
    #print t-test result
    print(t_out21)
    
    id21<-trt_dat21$Model# want to find these ids for time-series
    # create data-set for lme
    trt_dat21<- xeno21 %>% 
      filter(Treatment %in% c(unique_trt21[i], "untreated"))%>%
      filter(Model %in% xeno21[xeno21$Treatment==unique_trt21[i],]$Model)
    # select those with same Model name as that used
    trt_dat21<-trt_dat21 %>%
      filter(Model %in% id21)
    
    # perform model fits and output likelihood ratio-test
    trt_dat21<-trt_dat21[is.na(trt_dat21$Rad)==F,]
    trt_dat21$Treatment<-as.numeric(trt_dat21$Treatment!="untreated")
    model1 <- nlsLM(Rad ~ linear_growth_1(r0,g,data=trt_dat21),
                    trt_dat21, start = c(r0=3,g=0.01))
    
    # add treatment effect
    model2 <- nlsLM(Rad ~ linear_growth_2(r0,g,d,data=trt_dat21),
                    trt_dat21, start = c(r0=3,g=0.01,d=0.1))
    
    # anova test
    var_nls <- anova(model1, model2)
    var_nls
    # tidy format
    var_nls <- tidy(var_nls) 
    
    
    #create array of p-values
    p_vals21[i,1]<- unique_trt21[i]
    p_vals21[i,2]<- t_out21$p.value
    # TGI is defined as: 100*(V(control,t)-Volume(treated,t))/(V(control,t)-V(control,0))
    p_vals21[i,3]<-  100*as.numeric((t_out21$estimate[1]-t_out21$estimate[2])/
                                      (t_out21$estimate[2]-mean(trt_dat21$Volume.mm3[trt_dat21$Treatment==0 & trt_dat21$Days==0])))# this is measure of tumour growth inhibition
    
    p_vals21[i,4]<- as.numeric(t_out21$estimate[2]/
                                 t_out21$estimate[1])# this is measure of tumour growth inhibition
    p_vals21[i,5]<- var_nls$p.value[2]
    
  }, error=function(e){cat("ERROR :",conditionMessage(e), "\n")})
}


#Output t-test results 
#Dataframe of treatment and their p-value
p_vals21<- as_tibble(p_vals21)

#assign column names
colnames(p_vals21)<- c("Treatment","T-test","TGI","FoldChange","LRT")


#coerce p-values & TGI to numeric 
p_vals21$`T-test`<- as.numeric(as.character(p_vals21$`T-test`))
p_vals21$TGI<- as.numeric(as.character(p_vals21$TGI))
p_vals21$FoldChange<- as.numeric(as.character(p_vals21$FoldChange))
p_vals21$LRT<- as.numeric(as.character(p_vals21$LRT))

#view results
p_vals21



# Day 28 Analysis ---------------------------------------------------------

#create empty array to fill with t-test results for each treatment
p_vals28<- array(NA, dim = c(length(unique_trt28),5))
#for loop to perform t-test for each treatment
for(i in 1:length(unique_trt28)){
  tryCatch({
    #print treatment
    print(unique_trt28[i])
    #filter for treatment i and control arm for when model numbers match
    trt_dat28<- long_xeno_last28 %>% 
      filter(Treatment %in% c(unique_trt28[i], "untreated"))%>%
      filter(Model %in% long_xeno_last28[long_xeno_last28$Treatment==unique_trt28[i],]$Model)
    #perform paired t test for treatment i
    t_out28<- t.test(Volume.mm3 ~ Treatment, 
                     data=trt_dat28, 
                     paired=FALSE)# not sure this is really paired data
    #print t-test result
    print(t_out28)
    
    id28<-trt_dat28$Model# want to find these ids for time-series
    # create data-set for lme
    trt_dat28<- xeno28 %>% 
      filter(Treatment %in% c(unique_trt28[i], "untreated"))%>%
      filter(Model %in% xeno28[xeno28$Treatment==unique_trt28[i],]$Model)
    # select those with same Model name as that used
    trt_dat28<-trt_dat28 %>%
      filter(Model %in% id28)
    
    # perform model fits and output likelihood ratio-test
    trt_dat28<-trt_dat28[is.na(trt_dat28$Rad)==F,]
    trt_dat28$Treatment<-as.numeric(trt_dat28$Treatment!="untreated")
    model1 <- nlsLM(Rad ~ linear_growth_1(r0,g,data=trt_dat28),
                    trt_dat28, start = c(r0=3,g=0.01))
    
    # add treatment effect
    model2 <- nlsLM(Rad ~ linear_growth_2(r0,g,d,data=trt_dat28),
                    trt_dat28, start = c(r0=3,g=0.01,d=0.1))
    
    # anova test
    var_nls <- anova(model1, model2)
    var_nls
    # tidy format
    var_nls <- tidy(var_nls) 
    
    #create array of p-values
    p_vals28[i,1]<- unique_trt28[i]
    p_vals28[i,2]<- t_out28$p.value
    # TGI is defined as: 100*(V(control,t)-Volume(treated,t))/(V(control,t)-V(control,0))
    p_vals28[i,3]<-  100*as.numeric((t_out28$estimate[1]-t_out28$estimate[2])/
                                      (t_out28$estimate[2]-mean(trt_dat28$Volume.mm3[trt_dat28$Treatment==0 & trt_dat28$Days==0])))# this is measure of tumour growth inhibition
    
    p_vals28[i,4]<- as.numeric(t_out28$estimate[2]/t_out28$estimate[1])# this is measure of tumour growth inhibition
    p_vals28[i,5]<- var_nls$p.value[2]
  }, error=function(e){cat("ERROR :",conditionMessage(e), "\n")})
}


#Output t-test results 
#Dataframe of treatment and their p-value
p_vals28<- as_tibble(p_vals28)

#assign column names
colnames(p_vals28)<- c("Treatment","T-test","TGI","FoldChange","LRT")


#coerce p-values & TGI to numeric 
p_vals28$`T-test`<- as.numeric(as.character(p_vals28$`T-test`))
p_vals28$TGI<- as.numeric(as.character(p_vals28$TGI))
p_vals28$FoldChange<- as.numeric(as.character(p_vals28$FoldChange))
p_vals28$LRT<- as.numeric(as.character(p_vals28$LRT))

#view results
p_vals28


# Plot Results ------------------------------------------------------------

#omit NA values (where fit was unable to be obatined)
#day 14
p_vals14<- na.omit(p_vals14)
write_xlsx(p_vals14, "p_val_day14_NPA.xlsx")

#day 21
p_vals21<- na.omit(p_vals21)
write_xlsx(p_vals21, "p_val_day21_NPA.xlsx")
#day 28
p_vals28<- na.omit(p_vals28)
write_xlsx(p_vals28, "p_val_day28_NPA.xlsx")

p_vals14<- read_xlsx("p_val_day14_NPA.xlsx")
p_vals21<- read_xlsx("p_val_day21_NPA.xlsx")
p_vals28<- read_xlsx("p_val_day28_NPA.xlsx")

pval_limit<- 0.05

#same treatments for tumour volume at day 10 and day 28
p_val_filt_14<- p_vals14 %>% 
  filter(Treatment %in% p_vals28$Treatment)

p_val_filt_21<- p_vals21 %>% 
  filter(Treatment %in% p_val_filt_14$Treatment)

p_val_filt_28<- p_vals28 %>% 
  filter(Treatment %in% p_val_filt_14$Treatment)


tgi_comp<- as.data.frame(cbind(p_val_filt_14$TGI, p_val_filt_21$TGI,
                               p_val_filt_28$TGI))
colnames(tgi_comp)<- c("Day.14", "Day.21","Day.28")

tgi_comp$TRT <- p_val_filt_14$Treatment


# day 14
p_vals14$TGI<- p_vals14$TGI * -1 

p_vals14<- p_vals14[with(p_vals14, order(TGI)), ]
p_vals14$sig_count<- NA

p_vals14$sig_count<- ifelse(p_vals14$LRT < 0.05,1,0)
p_vals14$sig_count<- cumsum(p_vals14$sig_count)

p_vals14$cum_pval<- p_vals14$sig_count/nrow(p_vals14)
p_vals14$cum_pval<- round(p_vals14$cum_pval,digits = 2)

# day 21
p_vals21$TGI<- p_vals21$TGI * -1 

p_vals21<- p_vals21[with(p_vals21, order(TGI)), ]
p_vals21$sig_count<- NA

p_vals21$sig_count<- ifelse(p_vals21$LRT < 0.05,1,0)
p_vals21$sig_count<- cumsum(p_vals21$sig_count)

p_vals21$cum_pval<- p_vals21$sig_count/nrow(p_vals21)
p_vals21$cum_pval<- round(p_vals21$cum_pval,digits = 2)

# day 28
p_vals28$TGI<- p_vals28$TGI * -1 

p_vals28<- p_vals28[with(p_vals28, order(TGI)), ]
p_vals28$sig_count<- NA

p_vals28$sig_count<- ifelse(p_vals28$LRT < 0.05,1,0)
p_vals28$sig_count<- cumsum(p_vals28$sig_count)

p_vals28$cum_pval<- p_vals28$sig_count/nrow(p_vals28)
p_vals28$cum_pval<- round(p_vals28$cum_pval,digits = 2)


ggplot() +
  # geom_line(data=p_vals10, aes(x=TGI,y=cum_pval)) +
  geom_line(data=p_vals14, aes(x=TGI,y=cum_pval), col = "orange") +
  geom_line(data=p_vals21, aes(x=TGI,y=cum_pval), col = "red") +
  geom_line(data=p_vals28, aes(x=TGI,y=cum_pval), col = "green") +
  theme_bw() +
  xlab("TGI (%)") +
  ylab("Cumulative fraction of studies < 0.05")

#t-test

# day 14
p_vals14$sig_count_UT<- NA

p_vals14$sig_count_UT<- ifelse(p_vals14$`T-test`< 0.05,1,0)
p_vals14$sig_count_UT<- cumsum(p_vals14$sig_count_UT)

p_vals14$cum_pval_UT<- p_vals14$sig_count_UT/nrow(p_vals14)
p_vals14$cum_pval_UT<- round(p_vals14$cum_pval_UT,digits = 2)

# day 21
p_vals21$sig_count_UT<- NA

p_vals21$sig_count_UT<- ifelse(p_vals21$`T-test`< 0.05,1,0)
p_vals21$sig_count_UT<- cumsum(p_vals21$sig_count_UT)

p_vals21$cum_pval_UT<- p_vals21$sig_count_UT/nrow(p_vals21)
p_vals21$cum_pval_UT<- round(p_vals21$cum_pval_UT,digits = 2)

# day 28
p_vals28$sig_count_UT<- NA

p_vals28$sig_count_UT<- ifelse(p_vals28$`T-test` < 0.05,1,0)
p_vals28$sig_count_UT<- cumsum(p_vals28$sig_count_UT)

p_vals28$cum_pval_UT<- p_vals28$sig_count_UT/nrow(p_vals28)
p_vals28$cum_pval_UT<- round(p_vals28$cum_pval_UT,digits = 2)




#Data 2-day 14 t-test
dat2<- p_vals14[,c("TGI", "cum_pval_UT")]
colnames(dat2)<- c("TGI", "cum_pval")
dat2$day<- 14
dat2$test<- "t-test"
dat2$scenario <-"Day 14 t-test"

#Data 3-day 21 t-test
dat3<- p_vals21[,c("TGI", "cum_pval_UT")]
colnames(dat3)<- c("TGI", "cum_pval")
dat3$day<- 21
dat3$test<- "t-test"
dat3$scenario <-"Day 21 t-test"

#Data 4-day 28 t-test
dat4<- p_vals28[,c("TGI", "cum_pval_UT")]
colnames(dat4)<- c("TGI", "cum_pval")
dat4$day<- 28
dat4$test<- "t-test"
dat4$scenario <-"Day 28 t-test"



#Data 2-day 14 LRT
dat2.1<- p_vals14[,c("TGI", "cum_pval")]
dat2.1$day<- 14
dat2.1$test<- "LRT"
dat2.1$scenario <-"Day 14 model-based"

#Data 3-day 21 LRT
dat3.1<- p_vals21[,c("TGI", "cum_pval")]
dat3.1$day<- 21
dat3.1$test<- "LRT"
dat3.1$scenario <-"Day 21 model-based"

#Data 4-day 28 LRT
dat4.1<- p_vals28[,c("TGI", "cum_pval")]
dat4.1$day<- 28
dat4.1$test<- "LRT"
dat4.1$scenario <-"Day 28 model-based"

dat<- as.data.frame(rbind(dat2,dat3,dat4,dat2.1,dat3.1,dat4.1))

dat$test <- as.factor(dat$test)

dat$scenario <- as.factor(dat$scenario)

dat$scenario <- factor(dat$scenario, c("Day 14 model-based", "Day 21 model-based","Day 28 model-based",
                                       "Day 14 t-test","Day 21 t-test","Day 28 t-test"))
palette <- viridis(n = 3)
palette[3] <- "yellow3"

ggplot() +
  geom_line(data=dat, aes(x=TGI,y=cum_pval,col=factor(day),linetype=factor(test)), size= 0.7) +
  theme_bw(base_size = 14) +
  # scale_x_continuous(name = "TGI (%)", breaks = seq(-100,150,by=50)) +
  scale_y_continuous(name = "Cumulative fraction of studies < 0.05") +
  scale_color_manual(values = palette) +
  #scale_linetype_manual(values = c("solid","dashed"),labels = c("model-based", "t-test")) + 
  guides(color=guide_legend(title="Day"), linetype=guide_legend(title="Method")) +
  theme(legend.position = c(0.2,0.6))

#palette <- viridis(n=6)
#palette[6] <- "yellow3"

ggplot() +
  geom_line(data=dat, aes(x=TGI,y=cum_pval,col=scenario,linetype=scenario), size= 0.74) +
  theme_bw(base_size = 14) +
  scale_x_continuous(name = "TGI (%)", limits = c(0,170)) +
  scale_y_continuous(name = "Cumulative fraction of studies < 0.05") +
  scale_color_manual(values = rep(palette, times = 2)) +
  scale_linetype_manual(values = c("solid","solid","solid","dotdash","dotdash","dotdash")) + 
  #guides(color=guide_legend(title="Day"), linetype=guide_legend(title="Method")) +
  theme(legend.position = c(0.2,0.72),legend.title=element_blank())



# Compare to LME ----------------------------------------------------------

# mixed effect results
lme14<- read_xlsx("p_val_day14_v2.xlsx")
lme21<- read_xlsx("p_val_day21_v2.xlsx")
lme28<- read_xlsx("p_val_day28_v2.xlsx")


# day 14
lme14$TGI<- lme14$TGI * -1 

lme14<- lme14[with(lme14, order(TGI)), ]
lme14$sig_count<- NA

lme14$sig_count<- ifelse(lme14$LRT < 0.05,1,0)
lme14$sig_count<- cumsum(lme14$sig_count)

lme14$cum_pval<- lme14$sig_count/nrow(lme14)
lme14$cum_pval<- round(lme14$cum_pval,digits = 2)

# day 21
lme21$TGI<- lme21$TGI * -1 

lme21<- lme21[with(lme21, order(TGI)), ]
lme21$sig_count<- NA

lme21$sig_count<- ifelse(lme21$LRT < 0.05,1,0)
lme21$sig_count<- cumsum(lme21$sig_count)

lme21$cum_pval<- lme21$sig_count/nrow(lme21)
lme21$cum_pval<- round(lme21$cum_pval,digits = 2)

# day 28
lme28$TGI<- lme28$TGI * -1 

lme28<- lme28[with(lme28, order(TGI)), ]
lme28$sig_count<- NA

lme28$sig_count<- ifelse(lme28$LRT < 0.05,1,0)
lme28$sig_count<- cumsum(lme28$sig_count)

lme28$cum_pval<- lme28$sig_count/nrow(lme28)
lme28$cum_pval<- round(lme28$cum_pval,digits = 2)


#t-test

# day 14
lme14$sig_count_UT<- NA

lme14$sig_count_UT<- ifelse(lme14$`T-test`< 0.05,1,0)
lme14$sig_count_UT<- cumsum(lme14$sig_count_UT)

lme14$cum_pval_UT<- lme14$sig_count_UT/nrow(lme14)
lme14$cum_pval_UT<- round(lme14$cum_pval_UT,digits = 2)

# day 21
lme21$sig_count_UT<- NA

lme21$sig_count_UT<- ifelse(lme21$`T-test`< 0.05,1,0)
lme21$sig_count_UT<- cumsum(lme21$sig_count_UT)

lme21$cum_pval_UT<- lme21$sig_count_UT/nrow(lme21)
lme21$cum_pval_UT<- round(lme21$cum_pval_UT,digits = 2)

# day 28
lme28$sig_count_UT<- NA

lme28$sig_count_UT<- ifelse(lme28$`T-test` < 0.05,1,0)
lme28$sig_count_UT<- cumsum(lme28$sig_count_UT)

lme28$cum_pval_UT<- lme28$sig_count_UT/nrow(lme28)
lme28$cum_pval_UT<- round(lme28$cum_pval_UT,digits = 2)




#Data 2-day 14 naive pool
dat2.1<- p_vals14[,c("TGI", "cum_pval")]
dat2.1$day<- "Day 14"
dat2.1$test<- "naive pool"
dat2.1$scenario <-"Day 14 naive pool"

#Data 3-day 21 naive pool
dat3.1<- p_vals21[,c("TGI", "cum_pval")]
dat3.1$day<- "Day 21"
dat3.1$test<- "naive pool"
dat3.1$scenario <-"Day 21 naive pool"

#Data 4-day 28 naive pool
dat4.1<- p_vals28[,c("TGI", "cum_pval")]
dat4.1$day<- "Day 28"
dat4.1$test<- "naive pool"
dat4.1$scenario <-"Day 28 naive pool"


# lme data
#Data 2-day 14 mixed-effect
dat2.2<- lme14[,c("TGI", "cum_pval")]
dat2.2$day<- "Day 14"
dat2.2$test<- "mixed-effect"
dat2.2$scenario <-"Day 14 mixed-effect"

#Data 3-day 21 mixed-effect
dat3.2<- lme21[,c("TGI", "cum_pval")]
dat3.2$day<- "Day 21"
dat3.2$test<- "mixed-effect"
dat3.2$scenario <-"Day 21 mixed-effect"

#Data 4-day 28 mixed-effect
dat4.2<- lme28[,c("TGI", "cum_pval")]
dat4.2$day<- "Day 28"
dat4.2$test<- "mixed-effect"
dat4.2$scenario <-"Day 28 mixed-effect"


comp_dat<- bind_rows(dat2.2,dat3.2,dat4.2,dat2.1,dat3.1,dat4.1)

comp_dat$test <- as.factor(comp_dat$test)

comp_dat$day <- as.factor(comp_dat$day)


comp_dat$scenario <- factor(comp_dat$scenario, 
                            c("Day 14 mixed-effect", "Day 21 mixed-effect",
                              "Day 28 mixed-effect","Day 14 naive pool",
                              "Day 21 naive pool", "Day 28 naive pool"))


ggplot() +
  geom_line(data=comp_dat, aes(x=TGI,y=cum_pval,col=factor(day),linetype=factor(test)), size= 0.7) +
  theme_bw(base_size = 14) +
  # scale_x_continuous(name = "TGI (%)", breaks = seq(-100,150,by=50)) +
  scale_y_continuous(name = "Cumulative fraction of studies < 0.05") +
  scale_color_manual(values = palette) +
  #scale_linetype_manual(values = c("solid","dashed"),labels = c("model-based", "t-test")) + 
  guides(color=guide_legend(title="Day"), linetype=guide_legend(title="Method")) +
  theme(legend.position = c(0.2,0.6))

#palette <- viridis(n=6)
#palette[6] <- "yellow3"

ggplot() +
  geom_line(data=comp_dat, aes(x=TGI,y=cum_pval,col=scenario,linetype=scenario), size= 0.74) +
  theme_bw(base_size = 14) +
  scale_x_continuous(name = "TGI (%)", limits = c(0,170)) +
  scale_y_continuous(name = "Cumulative fraction of studies < 0.05", limits = c(0,1)) +
  scale_color_manual(values = rep(palette, times = 2)) +
  scale_linetype_manual(values = c("solid","solid","solid","dotdash","dotdash","dotdash")) + 
  #guides(color=guide_legend(title="Day"), linetype=guide_legend(title="Method")) +
  theme(legend.position = c(0.2,0.72),legend.title=element_blank())

ggplot() +
  geom_line(data=comp_dat, aes(x=TGI,y=cum_pval,col=scenario,linetype=test), size= 0.74) +
  theme_bw(base_size = 14) +
  scale_x_continuous(name = "TGI (%)", limits = c(0,170)) +
  scale_y_continuous(name = "Cumulative fraction of studies < 0.05", limits = c(0,1)) +
  scale_color_manual(values = rep(palette, times = 2)) +
  scale_linetype_manual(values = c("solid","dotdash")) + 
  guides(color=F) +
  facet_wrap(.~day) +
  theme(legend.position = c(0.09,0.89),legend.title=element_blank())
