require(ggplot2)
require(nlme)
require(writexl)
require(saemix)
# so from the xenograft residual error exploration , S.D. = 0.044


#######.........Simulation - Proportional error v1.........#######
#i wrote proportional 2 ways as not sure which is correct
#this is first version
# wrote ((4*pi/3)*(r0+d*time*( 1 + rnorm(length(time),mean = 0,sd=0.3)))^3)
#ie Y = 4/3*pi*(r*(1 + err))^3

# What we want to do is simulate a control curve and then
# treatments with different amount of TGI, so ranging from
# 25% to 100% with different sample sizes, 5 to 10, and with
# different length of study from 7, 10, 14 days

# So let's simulate a control treatment for 10 mice
# In general there wasn't much in the way of correlation 
# between intercept and slope, so we won't worry about
# a covariance matrix
set.seed(1234)
#create function of simulation
sim_fun <- function(TGI,n_arm,sd_resid,cv_gd,cv_r0,t_pts)
{
  mu_r<-3.5 # initial tumour radius
  mu_g<-0.1 # growth rate of control radius
  # we want to now pick a treated rate that will give us a TGI of X%
  # reduction in tumour volume at day 14
  # Vol(Day=14) = (4*pi/3)*(mu_r+mu_g*14)^3, this is the control volume at day 14
  # We want a X% reduction in TGI, so:
  # Vol(Day=14)*(1-X/100) + Vol(Day=0) = (4*pi/3)*(mu_r+mu_g*14 - mu_d*14)^3
  # mu_d = (mu_r + mu_g*14 -(((Vol(Day=14)-Vol(Day=0))*(1-X/100))*3/(4*pi))^(1/3))/14
  vol14_ctl <- (4*pi/3)*(mu_r+mu_g*t_pts[length(t_pts)])^3
  vol0_ctl <- (4*pi/3)*(mu_r+mu_g*t_pts[1])^3
  mu_d <- (mu_r+mu_g*t_pts[length(t_pts)] - 
    ((vol14_ctl - (TGI/100)*(vol14_ctl-vol0_ctl))*(3/(4*pi)))^(1/3))/t_pts[length(t_pts)]
  
  r0<-rnorm(n_arm*2,mean = mu_r, sd = cv_r0*mu_r)# 6.5% Coefficient of Variation taken from our data analysis
  g<-rnorm(n_arm,mean = mu_g, sd = cv_gd*mu_g)# 70% Coefficient of Variation taken from our data analysis
  d<-rnorm(n_arm,mean = mu_d, sd = cv_gd*mu_d)# 70% Coefficient of Variation taken from our data analysis
  
  # now we have our set of parameters to do the simulation
  time<-t_pts
  
  # 2 arms, 10 mice, 5 time-points
  n_row <- 2*n_arm*length(t_pts)
  # 4 columns: ID, Time, Vol, Trt
  ndat<-data.frame(array(NA,dim=c(n_row,4)))
  colnames(ndat)<-c("Id","Time","Vol","Trt")
  ndat[,1]<-c(rep(c(1:n_arm),each=length(t_pts)),
              rep(c((n_arm+1):(2*n_arm)),each=length(t_pts)))# ID
  ndat[,2]<-rep(time,times=n_arm*2)# DAY
  ndat[,4]<-c(rep("CTL",times=n_arm*length(t_pts)),rep("TRT",times=n_arm*length(t_pts)))
  # now let's simulate the controls
  for (ii in 1:n_arm){
    ndat[((ii-1)*length(time) + 1):(length(time)*ii),3]<-
      ((4*pi/3)*((r0[ii]+g[ii]*time)*( 1 +
                                       rnorm(length(time),mean = 0,sd=sd_resid)))^3)
  }
  # next simulate the treated
  for (ii in 1:n_arm){
    ndat[((ii-1)*length(time) + n_arm*length(t_pts)+1):(length(time)*ii + n_arm*length(t_pts)),3]<-
      ((4*pi/3)*((r0[ii + n_arm]+g[ii]*time - d[ii]*time)*( 1 +
                                            rnorm(length(time),mean = 0,sd=sd_resid)))^3)
  }
  ndat[ndat[,3]<0,3]<-0
  return(ndat)
  
}

# the values for sd_resid, cv_gd, cv_r0 are taken from our xenograft resdiual error exploration
test<-sim_fun(TGI=50,n_arm=10,sd_resid=0.044,cv_gd=0.7,cv_r0 = 0.065,t_pts=c(0,3,7,10,14,21,28))
ggplot(test,aes(Time,Vol,group=Id,col=Trt))+geom_line()+theme_bw(base_size=14)


# we probably want to look 50 & 100 % TGI
# 10, 14, 21, 28 day experiments
# 10, 8 and 5 mice in each arm


#number of simualtions
n_sim<- 1000

# 2 arms, 10 mice, 7 time-points
n_row <- 2*10*7

#list for simulation output
#filled in for loop
sim_out<- list()

#repeat simulation n times
for(i in 1:n_sim){
  tryCatch({
    sim_out[[i]]<- sim_fun(TGI=50,n_arm=10,sd_resid=0.044,cv_gd=0.7,
                           cv_r0 = 0.065,t_pts=c(0,3,7,10,14,21,28))
  }, error=function(e){cat("ERROR :",conditionMessage(e), "\n")})
}

#bind simulation results to form one dataframe
sim_out <- as.data.frame(do.call("rbind", sim_out))
#add radius column
sim_out$Rad<-(sim_out$Vol*3/(4*pi))^(1/3)

#sim_out<- sim_out[sim_out$Time < 14,]

#empty dataframe to fill with p-values
p_vals<- as.data.frame(array(NA, dim = c(n_sim, 4)))
#assign col names
colnames(p_vals)<- c("Run", "t-test","FoldChange", "LRT")
p_vals$Run <- 1:n_sim

# model for saemix
linear_growth_1<-function(psi,id,xidep) { 
  time<-xidep[,1]  
  r0<-psi[id,1]
  g<-psi[id,2]
  ypred<-r0+g*time
  return(ypred)
}
linear_growth_2<-function(psi,id,xidep) { 
  time<-xidep[,1] 
  trt<-xidep[,2]
  r0<-psi[id,1]
  g<-psi[id,2]
  d<-psi[id,3]
  ypred<-r0+(g-d*trt)*time
  return(ypred)
}

#for loop to perform t-test and LME for each run of the simulated data
for(ii in 1:n_sim){
  tryCatch({
    #subest to perform t-test and lme on
    sub_sim<- sim_out[((ii-1)*n_row + 1):(ii*n_row),]
    
    #t test
    t_out<- t.test(sub_sim$Vol[sub_sim$Trt=="CTL" & sub_sim$Time==28],
                   sub_sim$Vol[sub_sim$Trt=="TRT" & sub_sim$Time==28])
    sub_sim$Trt<-as.numeric(sub_sim$Trt!="CTL")
    # compare with mixed-effects
    saemix.data<-saemixData(name.data=sub_sim,header=TRUE,sep=" ",na=NA,
                            name.group=c("Id"),name.predictors=c("Time","Trt"),
                            name.response=c("Rad"),
                            units=list(x="day",y="mm"), name.X="Time")
    saemix.model<-saemixModel(model=linear_growth_1,
                              description="Linear growth of radius over time", 
                              psi0=matrix(c(1,1),ncol=2, byrow=TRUE,
                                          dimnames=list(NULL, c("r0","g"))),
                              transform.par=c(1,1),
                              fixed.estim=c(1,1),
                              covariance.model=matrix(c(1,0,0,1),ncol=2,byrow=TRUE),
                              omega.init=matrix(c(1,0,0,1),ncol=2,byrow=TRUE),
                              error.model="proportional")
    saemix.fit1<-saemix(saemix.model,saemix.data,list(seed=123456,nb.chains=5,
                                                      nbiter.saemix=c(1000,500)))
    saemix.model<-saemixModel(model=linear_growth_2,
                              description="Linear growth of radius over time", 
                              psi0=matrix(c(3,0.1,0.1),ncol=3, byrow=TRUE,
                                          dimnames=list(NULL, c("r0","g","d"))),
                              transform.par=c(1,1,1),
                              fixed.estim=c(1,1,1),
                              covariance.model=matrix(c(1,0,0,
                                                        0,1,0,
                                                        0,0,0),ncol=3,byrow=TRUE),
                              omega.init=matrix(c(1,0,0,
                                                  0,1,0,
                                                  0,0,1),ncol=3,byrow=TRUE),
                              error.model="proportional")
    saemix.fit2<-saemix(saemix.model,saemix.data,list(seed=123456,nb.chains=5,
                                                      nbiter.saemix=c(1000,500)))
    
    LRT<-pchisq(-2*saemix.fit1@results@ll.is+2*saemix.fit2@results@ll.is,
                     1,lower.tail = F)
    
    p_vals$`t-test`[ii]<- t_out$p.value #p value from t test
    p_vals$LRT[ii]<- LRT #p value from lme 
    p_vals$FoldChange[ii]<- as.numeric(t_out$estimate[2]/
                                         t_out$estimate[1]) #fold change
    
    
  }, error=function(e){cat("ERROR :",conditionMessage(e), "\n")})  
}


#coerce p-values & TGI to numeric 
p_vals$`t-test`<- as.numeric(as.character(p_vals$`t-test`))
p_vals$FoldChange<- as.numeric(as.character(p_vals$FoldChange))
p_vals$LRT<- as.numeric(as.character(p_vals$LRT))

#create colmun of log2(FoldChange)
p_vals$"Log2FoldChange"<- log(abs(p_vals$FoldChange))
#view results
p_vals

#save results
write_xlsx(p_vals, "sim_out_50T_10A_28D_v3.xlsx")

#Bonferroni adjusted p-value level of significance
pval_limit<- 0.05
#linit for significant change in tumour volume
FoldChange_limit<- 1


#add columns to assess significance and magnitude of fold change
#t-test
p_vals$t_colour<- "black"

#statistically significant
p_vals$t_colour<- ifelse(p_vals$`t-test`<pval_limit, "red",p_vals$t_colour)
#large fold change
p_vals$t_colour<- ifelse(abs(p_vals$Log2FoldChange)>FoldChange_limit, "orange",p_vals$t_colour)
#statistically significant and large fold change
p_vals$t_colour<- ifelse(p_vals$`t-test`<pval_limit & abs(p_vals$Log2FoldChange)>FoldChange_limit, 
                         "green",p_vals$t_colour)

#lme
p_vals$l_colour<- "black"

#statistically significant
p_vals$l_colour<- ifelse(p_vals$LRT<pval_limit, "red",p_vals$l_colour)
#large fold change
p_vals$l_colour<- ifelse(abs(p_vals$Log2FoldChange)>FoldChange_limit, "orange",p_vals$l_colour)
#statistically significant and large fold change
p_vals$l_colour<- ifelse(p_vals$LRT<pval_limit & abs(p_vals$Log2FoldChange)>FoldChange_limit,
                         "green",p_vals$l_colour)

(p_less_t<- 100*(sum(na.omit(p_vals$`t-test`< pval_limit)))/ nrow(p_vals))
(p_less_l<- 100*(sum(na.omit(p_vals$LRT< pval_limit)))/ nrow(p_vals))

#plot of LME p-values against t-test p-values
#dashed line is line of unity
ggplot(p_vals, aes(-log10(`t-test`), -log10(LRT))) +
  geom_point() +
  ggtitle("T-Test vs Linear Mixed Effect Model") +
  xlab("-log10(T-test p-value)") +
  ylab("-log10(LRT p-value)") + 
  geom_abline(aes(intercept = 0, slope = 1), linetype = "dashed", col = 2) +
  theme_bw()  +
  annotate(geom = 'rect',
           alpha = 0.2, fill = 'red',
           xmin = 0, xmax = -log10(pval_limit),
           ymin = 0, ymax = -log10(pval_limit))  +
  annotate(geom = 'text',
           fontface = 'bold',
           color = 'darkred',
           size  = 3,
           label = 'Statistically Insignificant', x = 2, y = 0.5)
#t-test
#plot log10(p-value) against Log2(FoldChange) of tumour growht inhibtion
#horizontal line is the Bonferroni adjusted p-value line of statitical significance
#green-statisically significant and large fold change
#amber-large fold change
#red-statistically significant
ggplot(p_vals,aes(Log2FoldChange, -log10(`t-test`), col = t_colour, alpha = 0.4)) +
  geom_point() +
  labs(title = "t-test", subtitle=(main= paste("Studies that have a p-value less than the
corrected p-value threshold of 0.05 = ", round(p_less_t, digit = 3), "%"))) +
  scale_colour_identity() + 
  theme_bw() +
  theme(legend.position="none") +
  xlab("log2(Fold Change)") +
  ylab("-log10 (p-value)") +
  geom_hline(aes(yintercept = -log10(pval_limit)), linetype = "dashed")

#t-test
#plot log10(p-value) against Log2(FoldChange) of tumour growht inhibtion
#horizontal line is the Bonferroni adjusted p-value line of statitical significance
#green-statisically significant and large fold change
#amber-large fold change
#red-statistically significant
ggplot(p_vals,aes(Log2FoldChange, -log10(LRT), col = l_colour, alpha = 0.4)) +
  geom_point() +
  labs(title = "Linear Mixed Effect", subtitle=(main= paste("Studies that have a p-value less than the
corrected p-value threshold of 0.05 = ", round(p_less_l, digit = 3), "%"))) +
  scale_colour_identity() + 
  theme_bw() +
  theme(legend.position="none") +
  xlab("log2(Fold Change)") +
  ylab("-log10 (p-value)") +
  geom_hline(aes(yintercept = -log10(pval_limit)), linetype = "dashed")


